pub struct FileContextManager { /* private fields */ }Expand description
Manages file content for context injection
Implementations
Sourceimpl FileContextManager
impl FileContextManager
Sourcepub fn compute_hash(content: &str) -> String
pub fn compute_hash(content: &str) -> String
Compute SHA256 hash of content
Sourcepub fn is_in_context(&self, path: &str) -> bool
pub fn is_in_context(&self, path: &str) -> bool
Check if a file is already in the current context
Sourcepub fn mark_in_context(&mut self, path: &str)
pub fn mark_in_context(&mut self, path: &str)
Mark a file as being in the current context
Sourcepub fn clear_context(&mut self)
pub fn clear_context(&mut self)
Clear the context tracking (for new conversation turns)
Sourcepub fn context_file_count(&self) -> usize
pub fn context_file_count(&self) -> usize
Get the number of files currently in context
Sourcepub async fn get_file_content(
&mut self,
path: &str,
query_context: Option<&str>,
) -> Result<FileContent>
pub async fn get_file_content( &mut self, path: &str, query_context: Option<&str>, ) -> Result<FileContent>
Get file content with smart routing based on size
Arguments
path- Path to the filequery_context- Optional query to use for finding relevant chunks
Returns
FileContent::Fullfor small filesFileContent::Chunkedfor large files with relevant portionsFileContent::AlreadyInContextif file was previously loaded
Sourcepub async fn get_file_lines(
&mut self,
path: &str,
start_line: usize,
end_line: usize,
) -> Result<FileContent>
pub async fn get_file_lines( &mut self, path: &str, start_line: usize, end_line: usize, ) -> Result<FileContent>
Get specific lines from a file
Sourcepub fn format_content(file_content: &FileContent) -> String
pub fn format_content(file_content: &FileContent) -> String
Format chunked content for display in context